========
Contents
========

.. toctree::
    :maxdepth: 1

    guide/index
    reference/index
    examples/index
    contributing
    authors
    license
    changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

